@@ -6,6 +6,9 @@ class Counter:
 
 	def count_content(self):
 		return len(self.fetcher.get_content().split())
+	
+	def get_fetcher(self):
+		return self.fetcher
 
 if __name__ == '__main__':
 	instance = Counter('/home/peretz/dependencies/assets/content.txt')
